@@ -79,11 +79,11 @@ def team_name_revise(team, source_input, source_output):
         row = df.loc[df[source_input] == team]
         result = row.iloc[0][source_output]
     except (IndexError, KeyError):
-        logger.waring(f'no register for {team}')
+        logger.warning(f'no register for {team}')
         result = team
         
     if(pd.isnull(result))   :
         result = team
-        logger.waring(f'blank cell in csv for {team}')
+        logger.warning(f'blank cell in csv for {team}')
     
     return result       
