@@ -22,7 +22,7 @@ from linebot.models import (
  ImageMessage, VideoMessage, AudioMessage, FlexSendMessage, 
  UnfollowEvent, FollowEvent, JoinEvent, LeaveEvent, BeaconEvent,
  FlexSendMessage, BubbleContainer, ImageComponent, BoxComponent,
- TextComponent, SpacerComponent, IconComponent, ButtonComponent,
+ TextComponent, IconComponent, ButtonComponent,
  SeparatorComponent, QuickReply, QuickReplyButton, PostbackAction,MessageAction, CarouselContainer
 
 )
